@@ -32,7 +32,7 @@ from oslo_utils import reflection
 if hasattr(time, 'monotonic'):
     now = time.monotonic
 else:
-    from time import monotonic as now  # noqa
+    from monotonic import monotonic as now  # noqa
 
 # ISO 8601 extended time format with microseconds
 _ISO8601_TIME_FORMAT_SUBSECOND = '%Y-%m-%dT%H:%M:%S.%f'
